.stock-lookup-widget {
  margin: 4px;
  background-color: white;
  padding: 0px 2px;
  border: 1px solid black;
  padding: 4px;
}

.stock-lookup-widget .hide-results {
  display: none;
}

.stock-lookup-widget .results_symbol {
  font-weight: bold;
}

